==> jc-1.4.0.tar.gz: java/util/Collections__24SynchronizedRandomAccessList.h <==
// final class java.util.Collections$SynchronizedRandomAccessList

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 49021d874f7b140b java_util_Collections__24SynchronizedCollection
// @dep_class 77e61ac61cf6abc0 java_util_Collections__24SynchronizedList
// @dep_class 209cd89d1f376630 java_util_Collections__24SynchronizedRandomAccessList

// header file dependencies
// @dep_header java_util_Collections__24SynchronizedList

#include "java/util/Collections__24SynchronizedList.h"

#ifndef _JC_java_util_Collections__24SynchronizedRandomAccessList_H_
#define _JC_java_util_Collections__24SynchronizedRandomAccessList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;

// Typedefs
typedef struct _jc_java_util_Collections__24SynchronizedRandomAccessList$sub_refs	_jc_java_util_Collections__24SynchronizedRandomAccessList$sub_refs;
typedef struct _jc_java_util_Collections__24SynchronizedRandomAccessList$sub_nonrefs	_jc_java_util_Collections__24SynchronizedRandomAccessList$sub_nonrefs;
typedef struct _jc_java_util_Collections__24SynchronizedRandomAccessList$refs	_jc_java_util_Collections__24SynchronizedRandomAccessList$refs;
typedef struct _jc_java_util_Collections__24SynchronizedRandomAccessList$nonrefs	_jc_java_util_Collections__24SynchronizedRandomAccessList$nonrefs;
typedef struct _jc_java_util_Collections__24SynchronizedRandomAccessList$object	_jc_java_util_Collections__24SynchronizedRandomAccessList$object;

typedef struct _jc_java_util_Collections__24SynchronizedRandomAccessList$fields_struct	_jc_java_util_Collections__24SynchronizedRandomAccessList$fields_struct;
typedef const struct _jc_java_util_Collections__24SynchronizedRandomAccessList$vmethods	_jc_java_util_Collections__24SynchronizedRandomAccessList$vmethods;
typedef const struct _jc_java_util_Collections__24SynchronizedRandomAccessList$vtable	_jc_java_util_Collections__24SynchronizedRandomAccessList$vtable;
typedef const struct _jc_java_util_Collections__24SynchronizedRandomAccessList$vtype	_jc_java_util_Collections__24SynchronizedRandomAccessList$vtype;

// Class fields structure
struct _jc_java_util_Collections__24SynchronizedRandomAccessList$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_Collections__24SynchronizedRandomAccessList$fields_struct _jc_java_util_Collections__24SynchronizedRandomAccessList$class_fields;

// Constructors
extern void _jc_java_util_Collections__24SynchronizedRandomAccessList$method$_init$6ee0de751e86c887(_jc_env *, struct _jc_java_util_Collections__24SynchronizedRandomAccessList$object *, struct _jc_java_lang_Object$object *, struct _jc_object *);
extern void _jc_java_util_Collections__24SynchronizedRandomAccessList$method$_init$dd8ff073a2c7f994(_jc_env *, struct _jc_java_util_Collections__24SynchronizedRandomAccessList$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_java_util_Collections__24SynchronizedRandomAccessList$method$subList$af8e3c69195dae35(_jc_env *, struct _jc_java_util_Collections__24SynchronizedRandomAccessList$object *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_java_util_Collections__24SynchronizedRandomAccessList$method_info$subList$af8e3c69195dae35;

// Virtual methods structure
struct _jc_java_util_Collections__24SynchronizedRandomAccessList$vmethods {
	struct _jc_object	*(*subList$af8e3c69195dae35)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedRandomAccessList$object *, jint, jint);
};

// Vtable
struct _jc_java_util_Collections__24SynchronizedRandomAccessList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_Collections__24SynchronizedCollection$vmethods	java_util_Collections__24SynchronizedCollection;
	_jc_java_util_Collections__24SynchronizedList$vmethods	java_util_Collections__24SynchronizedList;
	_jc_java_util_Collections__24SynchronizedRandomAccessList$vmethods	java_util_Collections__24SynchronizedRandomAccessList;
};

// Vtype
struct _jc_java_util_Collections__24SynchronizedRandomAccessList$vtype {
	_jc_type			type;
	_jc_java_util_Collections__24SynchronizedRandomAccessList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Collections__24SynchronizedRandomAccessList$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_Collections__24SynchronizedRandomAccessList$refs {
    _jc_java_util_Collections__24SynchronizedRandomAccessList$sub_refs	java_util_Collections__24SynchronizedRandomAccessList;
    _jc_java_util_Collections__24SynchronizedList$sub_refs	java_util_Collections__24SynchronizedList;
    _jc_java_util_Collections__24SynchronizedCollection$sub_refs	java_util_Collections__24SynchronizedCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Collections__24SynchronizedRandomAccessList$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_Collections__24SynchronizedRandomAccessList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_Collections__24SynchronizedCollection$sub_nonrefs	java_util_Collections__24SynchronizedCollection;
    _jc_java_util_Collections__24SynchronizedList$sub_nonrefs	java_util_Collections__24SynchronizedList;
    _jc_java_util_Collections__24SynchronizedRandomAccessList$sub_nonrefs	java_util_Collections__24SynchronizedRandomAccessList;
};

// Object instance structure
struct _jc_java_util_Collections__24SynchronizedRandomAccessList$object {
	_jc_java_util_Collections__24SynchronizedRandomAccessList$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Collections__24SynchronizedRandomAccessList$vtype	*vtype;
	_jc_java_util_Collections__24SynchronizedRandomAccessList$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Collections__24SynchronizedRandomAccessList$vtype _jc_java_util_Collections__24SynchronizedRandomAccessList$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Collections__24SynchronizedRandomAccessList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Collections__24SynchronizedRandomAccessList$class_object;

#endif	/* _JC_java_util_Collections__24SynchronizedRandomAccessList_H_ */

==> jc-1.4.6.tar.gz: java/util/Collections__24SynchronizedRandomAccessList.h <==
// final class java.util.Collections$SynchronizedRandomAccessList

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 49021d874f7b140b java_util_Collections__24SynchronizedCollection
// @dep_class 77e61ac61cf6abc0 java_util_Collections__24SynchronizedList
// @dep_class 209cd89d1f376630 java_util_Collections__24SynchronizedRandomAccessList

// header file dependencies
// @dep_header java_util_Collections__24SynchronizedList

#include "java/util/Collections__24SynchronizedList.h"

#ifndef _JC_java_util_Collections__24SynchronizedRandomAccessList_H_
#define _JC_java_util_Collections__24SynchronizedRandomAccessList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;

// Typedefs
typedef struct _jc_java_util_Collections__24SynchronizedRandomAccessList$sub_refs	_jc_java_util_Collections__24SynchronizedRandomAccessList$sub_refs;
typedef struct _jc_java_util_Collections__24SynchronizedRandomAccessList$sub_nonrefs	_jc_java_util_Collections__24SynchronizedRandomAccessList$sub_nonrefs;
typedef struct _jc_java_util_Collections__24SynchronizedRandomAccessList$refs	_jc_java_util_Collections__24SynchronizedRandomAccessList$refs;
typedef struct _jc_java_util_Collections__24SynchronizedRandomAccessList$nonrefs	_jc_java_util_Collections__24SynchronizedRandomAccessList$nonrefs;
typedef struct _jc_java_util_Collections__24SynchronizedRandomAccessList$object	_jc_java_util_Collections__24SynchronizedRandomAccessList$object;

typedef struct _jc_java_util_Collections__24SynchronizedRandomAccessList$fields_struct	_jc_java_util_Collections__24SynchronizedRandomAccessList$fields_struct;
typedef const struct _jc_java_util_Collections__24SynchronizedRandomAccessList$vmethods	_jc_java_util_Collections__24SynchronizedRandomAccessList$vmethods;
typedef const struct _jc_java_util_Collections__24SynchronizedRandomAccessList$vtable	_jc_java_util_Collections__24SynchronizedRandomAccessList$vtable;
typedef const struct _jc_java_util_Collections__24SynchronizedRandomAccessList$vtype	_jc_java_util_Collections__24SynchronizedRandomAccessList$vtype;

// Class fields structure
struct _jc_java_util_Collections__24SynchronizedRandomAccessList$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_Collections__24SynchronizedRandomAccessList$fields_struct _jc_java_util_Collections__24SynchronizedRandomAccessList$class_fields;

// Constructors
extern void _jc_java_util_Collections__24SynchronizedRandomAccessList$method$_init$6ee0de751e86c887(_jc_env *, struct _jc_java_util_Collections__24SynchronizedRandomAccessList$object *, struct _jc_java_lang_Object$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_java_util_Collections__24SynchronizedRandomAccessList$method$_init$dd8ff073a2c7f994(_jc_env *, struct _jc_java_util_Collections__24SynchronizedRandomAccessList$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_java_util_Collections__24SynchronizedRandomAccessList$method$subList$af8e3c69195dae35(_jc_env *, struct _jc_java_util_Collections__24SynchronizedRandomAccessList$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_Collections__24SynchronizedRandomAccessList$method_info$subList$af8e3c69195dae35;

// Virtual methods structure
struct _jc_java_util_Collections__24SynchronizedRandomAccessList$vmethods {
	struct _jc_object	*(*subList$af8e3c69195dae35)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedRandomAccessList$object *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_Collections__24SynchronizedRandomAccessList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_Collections__24SynchronizedCollection$vmethods	java_util_Collections__24SynchronizedCollection;
	_jc_java_util_Collections__24SynchronizedList$vmethods	java_util_Collections__24SynchronizedList;
	_jc_java_util_Collections__24SynchronizedRandomAccessList$vmethods	java_util_Collections__24SynchronizedRandomAccessList;
};

// Vtype
struct _jc_java_util_Collections__24SynchronizedRandomAccessList$vtype {
	_jc_type			type;
	_jc_java_util_Collections__24SynchronizedRandomAccessList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Collections__24SynchronizedRandomAccessList$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_Collections__24SynchronizedRandomAccessList$refs {
    _jc_java_util_Collections__24SynchronizedRandomAccessList$sub_refs	java_util_Collections__24SynchronizedRandomAccessList;
    _jc_java_util_Collections__24SynchronizedList$sub_refs	java_util_Collections__24SynchronizedList;
    _jc_java_util_Collections__24SynchronizedCollection$sub_refs	java_util_Collections__24SynchronizedCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Collections__24SynchronizedRandomAccessList$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_Collections__24SynchronizedRandomAccessList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_Collections__24SynchronizedCollection$sub_nonrefs	java_util_Collections__24SynchronizedCollection;
    _jc_java_util_Collections__24SynchronizedList$sub_nonrefs	java_util_Collections__24SynchronizedList;
    _jc_java_util_Collections__24SynchronizedRandomAccessList$sub_nonrefs	java_util_Collections__24SynchronizedRandomAccessList;
};

// Object instance structure
struct _jc_java_util_Collections__24SynchronizedRandomAccessList$object {
	_jc_java_util_Collections__24SynchronizedRandomAccessList$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Collections__24SynchronizedRandomAccessList$vtype	*vtype;
	_jc_java_util_Collections__24SynchronizedRandomAccessList$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Collections__24SynchronizedRandomAccessList$vtype _jc_java_util_Collections__24SynchronizedRandomAccessList$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Collections__24SynchronizedRandomAccessList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Collections__24SynchronizedRandomAccessList$class_object;

#endif	/* _JC_java_util_Collections__24SynchronizedRandomAccessList_H_ */
